Webgeodyn: visualisation tools for the geomagnetic field and motions of the Earth's liquid core

Streamfunctions at the Core-Mantle Boundary, superimposed with scalar fields
(e.g. radial magnetic field, flow norm... under several projections)
Earth's core surface (Aitoff projection)
Orthographic projection
Time-position maps of scalar fields (including geostrophic flow)
(with respect to longitude, latitude or curvilinear coordinates)
Cross-section of secular variation along Φ
Time series of spherical harmonics coefficients of core quantities
Time series of spherical harmonics coefficients
Time series of length-of-day variation
derived from core flows
Comparison of LOD derived from core flows with the actual data
Mauersberger-Lowes spectra of the core quantities
for time-average, deviation or at a given date
Spectra of averaged core quantities
Comparison of model predictions with observatories
(ground-based observatory series and virtual observatory series)
Comparison with observatories